seq

Function seq 

pub fn seq<'i>(a: Parser<'i>, b: Parser<'i>) -> Parser<'i>
Sequence: match a then b, accumulating tokens from both.

If a fails, the whole seq fails with no input consumed. If a succeeds but b fails (or errors), the whole seq backtracks to the state before a.