pub struct LoaderOptions {
pub max_nesting_depth: usize,
pub max_anchors: usize,
pub max_expanded_nodes: usize,
pub mode: LoadMode,
}Expand description
Security and behaviour options for the loader.
Fields
max_nesting_depth: usizeMaximum mapping/sequence nesting depth (default: 512).
max_anchors: usizeMaximum number of distinct anchor names per document (default: 10 000).
max_expanded_nodes: usizeMaximum total nodes produced by alias expansion, resolved mode only (default: 1 000 000).
mode: LoadModeLoader mode.