pub struct LoaderOptions {
pub max_nesting_depth: usize,
pub max_anchors: usize,
pub max_expanded_nodes: usize,
pub mode: LoadMode,
pub schema: Schema,
}Expand description
Security and behaviour options for the loader.
Fields
max_nesting_depth: usizeMaximum mapping/sequence nesting depth before returning
LoadError::NestingDepthLimitExceeded (default: 512).
max_anchors: usizeMaximum number of distinct anchor names per document before returning
LoadError::AnchorCountLimitExceeded (default: 10 000).
max_expanded_nodes: usizeMaximum total nodes produced by alias expansion in resolved mode before
returning LoadError::AliasExpansionLimitExceeded (default: 1 000 000).
mode: LoadModeControls how alias references are handled during loading.
schema: SchemaYAML 1.2.2 10 schema to apply during loading (default: Schema::Core).
Each node’s tag is resolved according to this schema after the node is constructed. Nodes with explicit source tags are left unchanged.